@@ -175,6 +175,7 @@ l7vs_config_callback(struct l7vs_iomux *iom, int flags)
         cmsg = (struct cmsghdr *)cbuf;
         cmsg->cmsg_len = sizeof(cbuf);
 
+        memset(&addr, 0, sizeof(addr));
         memset(&msg, 0, sizeof(msg));
         msg.msg_name = &addr;
         msg.msg_namelen = sizeof(addr);
@@ -398,6 +399,7 @@ l7vs_config_add_vs(union l7vs_config_req *arg,
                 /* Send Trap message to l7vsagent process */
                 check_process_l7vsagent(trap_message);
 	}
+	free(srvname);
 
 out:
         l7vs_config_send_response(addr, &iov, 1);
@@ -444,7 +446,7 @@ l7vs_config_del_vs(union l7vs_config_req *arg,
 
         /* Send Trap message to l7vsagent process */
         check_process_l7vsagent(trap_message);
-
+	free(srvname);
 out:
         l7vs_config_send_response(addr, &iov, 1);
 }
@@ -542,6 +544,8 @@ l7vs_config_add_rs(union l7vs_config_req *arg,
         /* Send Trap message to l7vsagent process */
         check_process_l7vsagent(trap_message);
 
+	free(srvname);
+	free(srvname_temp);
 out:
         l7vs_config_send_response(addr, &iov, 1);
 }
@@ -593,6 +597,8 @@ l7vs_config_del_rs(union l7vs_config_req *arg,
         /* Send Trap message to l7vsagent process */
         check_process_l7vsagent(trap_message);
 
+	free(srvname);
+	free(srvname_temp);
 out:
         l7vs_config_send_response(addr, &iov, 1);
 }
@@ -795,8 +801,10 @@ static void stop_l7sync_daemons()
 	FILE *fp;
 	fp=fopen("/etc/init.d/l7syncd","r");
         if (fp != NULL)
+	{
 		system("/etc/init.d/l7syncd stopall");
-        fclose(fp);
+        	fclose(fp);
+	}
 }
 
 void shared_mem_sem_remove(key_t shmid, key_t sema_id)
