@@ -353,7 +353,7 @@ l7vs_conn_recv_client(struct l7vs_conn *conn)
 {
         int ret;
         char *newbuf;
-        fd_set rfds;
+        my_fd_set rfds;
         struct timeval tv;
 
         /*
@@ -389,8 +389,8 @@ l7vs_conn_recv_client(struct l7vs_conn *conn)
                 FD_ZERO(&rfds);
                 tv.tv_sec = 0;
                 tv.tv_usec = 0;
-                FD_SET(conn->ciom.fd, &rfds);
-                ret = select(conn->ciom.fd + 1, &rfds, NULL, NULL, &tv);
+                FD_SET(conn->ciom.fd, (fd_set *)&rfds);
+                ret = select(conn->ciom.fd + 1, (fd_set *)&rfds, NULL, NULL, &tv);
                 if (ret == 0) {
                         break;
                 } else if (ret < 0) {
@@ -414,6 +414,7 @@ l7vs_conn_relay(struct l7vs_conn *conn, int is_client)
         int ret, len, len_ret;
         int (*relayf)(struct l7vs_service *, struct l7vs_conn *,
                        char *, size_t *);
+        memset(buf, 0, L7VS_CONN_RELAY_BUFSIZE + L7VS_PROTOMOD_MAX_ADD_BUFSIZE);
 
         relayf = NULL;
         if (is_client) {
