@@ -959,7 +959,7 @@ operate_rs(int s, struct l7vsadm_options *opt)
 {
         struct l7vs_protomod *pm;
         struct l7vs_service_arg *sarg;
-        struct l7vs_config_req_operate_rs req;
+        struct l7vs_config_req_operate_rs req = {0};
         struct l7vs_config_rsp_operate_rs rsp;
         struct iovec iov[2];
         char *opstr;
