@@ -96,14 +96,14 @@ l7vs_lsock_get(struct sockaddr_in *sin, u_int8_t proto, int backlog)
 
         VANESSA_LOGGER_DEBUG_UNSAFE("creating lsock %p", lsock);
         lsock->proto = proto;
-        lsock->iom.fd = socket(PF_INET, stype, proto);
+        lsock->iom.fd = socket(PF_INET, stype, proto);  //create a socket to get connection request from the client
         if (lsock->iom.fd < 0) {
                 VANESSA_LOGGER_ERR_UNSAFE("socket: %s", strerror(errno));
                 free(lsock);
                 return NULL;
         }
 
-        ret = bind(lsock->iom.fd, (struct sockaddr *)sin, sizeof(*sin));
+        ret = bind(lsock->iom.fd, (struct sockaddr *)sin, sizeof(*sin)); //binding the socket for incoming client request
         if (ret < 0) {
                 VANESSA_LOGGER_ERR_UNSAFE("Could not bind socket: %s",
                                           strerror(errno));
@@ -113,7 +113,7 @@ l7vs_lsock_get(struct sockaddr_in *sin, u_int8_t proto, int backlog)
         }
         lsock->addr = *sin;
 
-        ret = listen(lsock->iom.fd, backlog);
+        ret = listen(lsock->iom.fd, backlog); //listening for client requests
         if (ret < 0) {
                 VANESSA_LOGGER_ERR_UNSAFE("Could not listen: %s\n",
                                           strerror(errno));
@@ -126,7 +126,7 @@ l7vs_lsock_get(struct sockaddr_in *sin, u_int8_t proto, int backlog)
 
         lsock->iom.callback = l7vs_lsock_callback;
         lsock->iom.data = lsock;
-        l7vs_lsock_table_add(lsock);
+        l7vs_lsock_table_add(lsock);  //Add socket in the list. It may be used for maintaining session (Am not sure)
         l7vs_iomux_add(&lsock->iom, L7VS_IOMUX_READ);
 
         return lsock;
@@ -174,7 +174,7 @@ l7vs_lsock_table_lookup(struct sockaddr_in *sin, u_int8_t proto)
                                l7vs_lsock_addr_cmp);
         if (l == NULL)
                 return NULL;
-        return (struct l7vs_lsock *)l->data;
+        return (struct l7vs_lsock *)l->data;  //for checking up and finding the socket in the list for a particular client socket(not sure)
 }
 
 static gint
@@ -272,7 +272,7 @@ l7vs_lsock_callback(struct l7vs_iomux *iom, int flags)
                 return L7VS_IOMUX_LIST_UNCHANGED;
         }
 
-        l7vs_lsock_accept((struct l7vs_lsock *)iom->data);
+        l7vs_lsock_accept((struct l7vs_lsock *)iom->data); //for accepting data from clients
 
         return L7VS_IOMUX_LIST_UNCHANGED;
 }
