@@ -304,6 +304,9 @@ l7vs_service_lookup(struct l7vs_service_arg *arg) //checks if the virtual servic
                 pmod->destroy(s);
                 return sref;
         }
+        if (s != NULL) {
+                pmod->destroy(s);
+        } 
         return NULL;
 }
 
