@@ -25,10 +25,8 @@ void stop_server(int sig) {
 /* This method checks the trap and is raised by config.c whenever there is a change
 *  in the L7VS Kernel Table */
 void check_l7vs_trap(int sig) {
-
-	char trap_message[BUFSIZ];
+	char trap_message[BUFSIZ]; //original
 	char *wordToken;
-
 	/* With combination of WHILE Loop and trap_loop_enter setting, we could allow
 	*  the Queuing up of SIGUSR1 requests */
 	while (keep_running)
@@ -55,7 +53,8 @@ void check_l7vs_trap(int sig) {
 				else
 				{
 					/* The actual trap is raised here */
-					raise_trap(trap_message);
+					printf("Calling from raise_trap and trap message is\t %s\n",trap_message);
+					raise_trap(trap_message); 
 				}
 			}
 
@@ -604,7 +603,9 @@ int populateReal(int socket_num, struct l7vs_service_arg *sarg, int virt_service
 
 			pRealEntry->l7vsRealServerWeight = darg[i].weight;
 			pRealEntry->l7vsRealServerActiveConn = darg[i].nactive;
-			pRealEntry->l7vsRealServerInactiveConn = darg[i].ninact;
+			pRealEntry->l7vsRealServerInactiveConn = darg[i].ninact; 
+			//pRealEntry->l7vsRealServerInactiveConn =333 ; // madhu
+			//strcpy(pRealEntry->l7vsRealServerInactiveConn, (char *)darg[i].ninact); //madhu
 		}
 			free(srvname);
 	}
@@ -694,7 +695,7 @@ int main(int argc, char ** argv)
 
 	int agentx_subagent=1; /* change this if you want to be a SNMP master agent */
 	int background = 0; /* change this if you want to run in the background */
-	int syslog = 0; /* change this if you want to use syslog */
+	int syslog = 1; /* change this if you want to use syslog */
 
 	vanessa_logger_t *vl;
 
@@ -813,7 +814,7 @@ int main(int argc, char ** argv)
 
 	/* The method check_l7vs_trap is called whenever there is a SIGUSR1 event.
 	*  SIGUSR1 is called from config.c whenever there is a change in the L7VS Kernel Table */
-	actUSR1.sa_handler = check_l7vs_trap;
+	actUSR1.sa_handler = check_l7vs_trap; 
 	sigemptyset(&actUSR1.sa_mask);
 	actUSR1.sa_flags = 0;
 	sigaction(SIGUSR1, &actUSR1, 0);
